PhoneNumber class

Phone number.

Constructors

PhoneNumber(int countryCode, String nationalNumber)
Creates a phone number.
const

Properties

countryCode → int
Country code.
final
hashCode → int
The hash code for this object.
no setterinherited
nationalNumber → String
National number.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited