Response class

EasySMS response.

Constructors

Response({required Gateway gateway, required PhoneNumber to, required bool success, required Response response})
const

Properties

gateway → Gateway
final
hashCode → int
The hash code for this object.
no setterinherited
response → Response
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final
to → PhoneNumber
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited