Strategy class abstract

Implementers

Constructors

Strategy()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
select(Iterable<Gateway> gateways) → Future<Gateway>
Select a gateway
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

or(Iterable<Gateway> gateways, {Gateway or(Iterable<Gateway> gateways)?}) → Gateway
Returns single gateway if gateways is single, otherwise returns or callback result.